Datasets — skchange

Skip to main content
`Ctrl`+`K`

# Datasets

## Generate toy data

`generate_anomalous_data`([n, anomalies, ...]) | Generate multivariate normal data with anomalies.
`generate_changing_data`([n, changepoints, ...]) | Generate piecewise multivariate normal data with changing means and variances.
`generate_alternating_data`(n_segments, ...[, ...]) | Generate multivariate normal data that is alternating between two states.
`add_linspace_outliers`(df, n_outliers, ...) | Add outliers to a DataFrame at evenly spaced positions.

## Load real datasets

`load_hvac_system_data`() | Load the heating, ventilation and air conditioning (HVAC) system dataset.